@@ -90,6 +90,12 @@ def main():
             help='Randomize the savegame GUID',
             )
 
+    parser.add_argument('--zero-guardian-rank',
+            dest='zero_guardian_rank',
+            action='store_true',
+            help='Zero out savegame Guardian Rank',
+            )
+
     levelgroup = parser.add_mutually_exclusive_group()
 
     levelgroup.add_argument('--level',
@@ -144,12 +150,19 @@ def main():
             help='Set Eridium value',
             )
 
+    parser.add_argument('--clear-takedowns',
+            dest='clear_takedowns',
+            action='store_true',
+            help='Clears out the Takedown Discovery missions so they don\'t clutter your UI',
+            )
+
     unlock_choices = [
             'ammo', 'backpack',
             'analyzer', 'resonator',
             'gunslots', 'artifactslot', 'comslot', 'allslots',
             'tvhm',
             'vehicles', 'vehicleskins',
+            'cubepuzzle',
             ]
     parser.add_argument('--unlock',
             action=cli_common.DictAction,
@@ -273,10 +286,12 @@ def main():
         args.name,
         args.save_game_id is not None,
         args.randomize_guid,
+        args.zero_guardian_rank,
         args.level is not None,
         args.mayhem is not None,
         args.money is not None,
         args.eridium is not None,
+        args.clear_takedowns,
         len(args.unlock) > 0,
         args.copy_nvhm,
         args.import_items,
@@ -311,6 +326,12 @@ def main():
                 print(' - Randomizing savegame GUID')
             save.randomize_guid()
 
+        # Zeroing Guardian Rank
+        if args.zero_guardian_rank:
+            if not args.quiet:
+                print(' - Zeroing Guardian Rank')
+            save.zero_guardian_rank()
+
         # Mayhem Level
         if args.mayhem is not None:
             if not args.quiet:
@@ -339,6 +360,12 @@ def main():
                 print(' - Setting Eridium to: {}'.format(args.eridium))
             save.set_eridium(args.eridium)
 
+        # Clearing Takedown Discovery
+        if args.clear_takedowns:
+            if not args.quiet:
+                print(' - Clearing Takedown Discovery missions')
+            save.clear_takedown_discovery()
+
         # Unlocks
         if len(args.unlock) > 0:
             if not args.quiet:
@@ -406,6 +433,12 @@ def main():
                     print('   - TVHM')
                 save.set_playthroughs_completed(1)
 
+            # Eridian Cube puzzle
+            if 'cubepuzzle' in args.unlock:
+                if not args.quiet:
+                    print('   - Eridian Cube Puzzle')
+                save.unlock_cube_puzzle()
+
         # Import Items
         if args.import_items:
             cli_common.import_items(args.import_items,
